# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['aceye']

package_data = \
{'': ['*'],
 'aceye': ['ARP Adjacency Endpoints/CSV/*',
           'ARP Adjacency Endpoints/HTML/*',
           'ARP Adjacency Endpoints/JSON/*',
           'ARP Adjacency Endpoints/Markdown/*',
           'ARP Adjacency Endpoints/Mindmap/*',
           'ARP Adjacency Endpoints/YAML/*',
           'ARP Database/CSV/*',
           'ARP Database/HTML/*',
           'ARP Database/JSON/*',
           'ARP Database/Markdown/*',
           'ARP Database/Mindmap/*',
           'ARP Database/YAML/*',
           'ARP Domain/CSV/*',
           'ARP Domain/HTML/*',
           'ARP Domain/JSON/*',
           'ARP Domain/Markdown/*',
           'ARP Domain/Mindmap/*',
           'ARP Domain/YAML/*',
           'ARP Entity/CSV/*',
           'ARP Entity/HTML/*',
           'ARP Entity/JSON/*',
           'ARP Entity/Markdown/*',
           'ARP Entity/Mindmap/*',
           'ARP Entity/YAML/*',
           'ARP Instances/CSV/*',
           'ARP Instances/HTML/*',
           'ARP Instances/JSON/*',
           'ARP Instances/Markdown/*',
           'ARP Instances/Mindmap/*',
           'ARP Instances/YAML/*',
           'ARP Interfaces/CSV/*',
           'ARP Interfaces/HTML/*',
           'ARP Interfaces/JSON/*',
           'ARP Interfaces/Markdown/*',
           'ARP Interfaces/Mindmap/*',
           'ARP Interfaces/YAML/*',
           'Access Bundle Groups/CSV/*',
           'Access Bundle Groups/HTML/*',
           'Access Bundle Groups/JSON/*',
           'Access Bundle Groups/Markdown/*',
           'Access Bundle Groups/Mindmap/*',
           'Access Bundle Groups/YAML/*',
           'Access Control Entities/CSV/*',
           'Access Control Entities/HTML/*',
           'Access Control Entities/JSON/*',
           'Access Control Entities/Markdown/*',
           'Access Control Entities/Mindmap/*',
           'Access Control Entities/YAML/*',
           'Access Control Instances/CSV/*',
           'Access Control Instances/HTML/*',
           'Access Control Instances/JSON/*',
           'Access Control Instances/Markdown/*',
           'Access Control Instances/Mindmap/*',
           'Access Control Instances/YAML/*',
           'Access Control Rules/CSV/*',
           'Access Control Rules/HTML/*',
           'Access Control Rules/JSON/*',
           'Access Control Rules/Markdown/*',
           'Access Control Rules/Mindmap/*',
           'Access Control Rules/YAML/*',
           'Access Control Scopes/CSV/*',
           'Access Control Scopes/HTML/*',
           'Access Control Scopes/JSON/*',
           'Access Control Scopes/Markdown/*',
           'Access Control Scopes/Mindmap/*',
           'Access Control Scopes/YAML/*',
           'Access Policy Group Source Relationships/CSV/*',
           'Access Policy Group Source Relationships/HTML/*',
           'Access Policy Group Source Relationships/JSON/*',
           'Access Policy Group Source Relationships/Markdown/*',
           'Access Policy Group Source Relationships/Mindmap/*',
           'Access Policy Group Source Relationships/YAML/*',
           'Access Port Groups/CSV/*',
           'Access Port Groups/HTML/*',
           'Access Port Groups/JSON/*',
           'Access Port Groups/Markdown/*',
           'Access Port Groups/Mindmap/*',
           'Access Port Groups/YAML/*',
           'Access Port Profiles/CSV/*',
           'Access Port Profiles/HTML/*',
           'Access Port Profiles/JSON/*',
           'Access Port Profiles/Markdown/*',
           'Access Port Profiles/Mindmap/*',
           'Access Port Profiles/YAML/*',
           'Application Profiles/CSV/*',
           'Application Profiles/HTML/*',
           'Application Profiles/JSON/*',
           'Application Profiles/Markdown/*',
           'Application Profiles/Mindmap/*',
           'Application Profiles/YAML/*',
           'Attachable Access Entity Profiles Source Relationships/CSV/*',
           'Attachable Access Entity Profiles Source Relationships/HTML/*',
           'Attachable Access Entity Profiles Source Relationships/JSON/*',
           'Attachable Access Entity Profiles Source Relationships/Markdown/*',
           'Attachable Access Entity Profiles Source Relationships/Mindmap/*',
           'Attachable Access Entity Profiles Source Relationships/YAML/*',
           'Attachable Access Entity Profiles/CSV/*',
           'Attachable Access Entity Profiles/HTML/*',
           'Attachable Access Entity Profiles/JSON/*',
           'Attachable Access Entity Profiles/Markdown/*',
           'Attachable Access Entity Profiles/Mindmap/*',
           'Attachable Access Entity Profiles/YAML/*',
           'Audit Log/CSV/*',
           'Audit Log/HTML/*',
           'Audit Log/JSON/*',
           'Audit Log/Markdown/*',
           'Audit Log/Mindmap/*',
           'Audit Log/YAML/*',
           'BGP Domain Address Families/CSV/*',
           'BGP Domain Address Families/HTML/*',
           'BGP Domain Address Families/JSON/*',
           'BGP Domain Address Families/Markdown/*',
           'BGP Domain Address Families/Mindmap/*',
           'BGP Domain Address Families/YAML/*',
           'BGP Domains/CSV/*',
           'BGP Domains/HTML/*',
           'BGP Domains/JSON/*',
           'BGP Domains/Markdown/*',
           'BGP Domains/Mindmap/*',
           'BGP Domains/YAML/*',
           'BGP Entities/CSV/*',
           'BGP Entities/HTML/*',
           'BGP Entities/JSON/*',
           'BGP Entities/Markdown/*',
           'BGP Entities/Mindmap/*',
           'BGP Entities/YAML/*',
           'BGP Instances Policy/CSV/*',
           'BGP Instances Policy/HTML/*',
           'BGP Instances Policy/JSON/*',
           'BGP Instances Policy/Markdown/*',
           'BGP Instances Policy/Mindmap/*',
           'BGP Instances Policy/YAML/*',
           'BGP Instances/CSV/*',
           'BGP Instances/HTML/*',
           'BGP Instances/JSON/*',
           'BGP Instances/Markdown/*',
           'BGP Instances/Mindmap/*',
           'BGP Instances/YAML/*',
           'BGP Peers AF Entries/CSV/*',
           'BGP Peers AF Entries/HTML/*',
           'BGP Peers AF Entries/JSON/*',
           'BGP Peers AF Entries/Markdown/*',
           'BGP Peers AF Entries/Mindmap/*',
           'BGP Peers AF Entries/YAML/*',
           'BGP Peers Entries/CSV/*',
           'BGP Peers Entries/HTML/*',
           'BGP Peers Entries/JSON/*',
           'BGP Peers Entries/Markdown/*',
           'BGP Peers Entries/Mindmap/*',
           'BGP Peers Entries/YAML/*',
           'BGP Peers/CSV/*',
           'BGP Peers/HTML/*',
           'BGP Peers/JSON/*',
           'BGP Peers/Markdown/*',
           'BGP Peers/Mindmap/*',
           'BGP Peers/YAML/*',
           'BGP Route Reflector Policies/CSV/*',
           'BGP Route Reflector Policies/HTML/*',
           'BGP Route Reflector Policies/JSON/*',
           'BGP Route Reflector Policies/Markdown/*',
           'BGP Route Reflector Policies/Mindmap/*',
           'BGP Route Reflector Policies/YAML/*',
           'BGP Route Reflectors/CSV/*',
           'BGP Route Reflectors/HTML/*',
           'BGP Route Reflectors/JSON/*',
           'BGP Route Reflectors/Markdown/*',
           'BGP Route Reflectors/Mindmap/*',
           'BGP Route Reflectors/YAML/*',
           'Bridge Domains Target Relationships/CSV/*',
           'Bridge Domains Target Relationships/HTML/*',
           'Bridge Domains Target Relationships/JSON/*',
           'Bridge Domains Target Relationships/Markdown/*',
           'Bridge Domains Target Relationships/Mindmap/*',
           'Bridge Domains Target Relationships/YAML/*',
           'Bridge Domains To Outside/CSV/*',
           'Bridge Domains To Outside/HTML/*',
           'Bridge Domains To Outside/JSON/*',
           'Bridge Domains To Outside/Markdown/*',
           'Bridge Domains To Outside/Mindmap/*',
           'Bridge Domains To Outside/YAML/*',
           'Bridge Domains/CSV/*',
           'Bridge Domains/HTML/*',
           'Bridge Domains/JSON/*',
           'Bridge Domains/Markdown/*',
           'Bridge Domains/Mindmap/*',
           'Bridge Domains/YAML/*',
           'CDP Adjacency Endpoints/CSV/*',
           'CDP Adjacency Endpoints/HTML/*',
           'CDP Adjacency Endpoints/JSON/*',
           'CDP Adjacency Endpoints/Markdown/*',
           'CDP Adjacency Endpoints/Mindmap/*',
           'CDP Adjacency Endpoints/YAML/*',
           'CDP Entities/CSV/*',
           'CDP Entities/HTML/*',
           'CDP Entities/JSON/*',
           'CDP Entities/Markdown/*',
           'CDP Entities/Mindmap/*',
           'CDP Entities/YAML/*',
           'CDP Instances/CSV/*',
           'CDP Instances/HTML/*',
           'CDP Instances/JSON/*',
           'CDP Instances/Markdown/*',
           'CDP Instances/Mindmap/*',
           'CDP Instances/YAML/*',
           'CDP Interface Addresses/CSV/*',
           'CDP Interface Addresses/HTML/*',
           'CDP Interface Addresses/JSON/*',
           'CDP Interface Addresses/Markdown/*',
           'CDP Interface Addresses/Mindmap/*',
           'CDP Interface Addresses/YAML/*',
           'CDP Interfaces/CSV/*',
           'CDP Interfaces/HTML/*',
           'CDP Interfaces/JSON/*',
           'CDP Interfaces/Markdown/*',
           'CDP Interfaces/Mindmap/*',
           'CDP Interfaces/YAML/*',
           'CDP Management Addresses/CSV/*',
           'CDP Management Addresses/HTML/*',
           'CDP Management Addresses/JSON/*',
           'CDP Management Addresses/Markdown/*',
           'CDP Management Addresses/Mindmap/*',
           'CDP Management Addresses/YAML/*',
           'Cluster Aggregate Interfaces/CSV/*',
           'Cluster Aggregate Interfaces/HTML/*',
           'Cluster Aggregate Interfaces/JSON/*',
           'Cluster Aggregate Interfaces/Markdown/*',
           'Cluster Aggregate Interfaces/Mindmap/*',
           'Cluster Aggregate Interfaces/YAML/*',
           'Cluster Health/CSV/*',
           'Cluster Health/HTML/*',
           'Cluster Health/JSON/*',
           'Cluster Health/Markdown/*',
           'Cluster Health/Mindmap/*',
           'Cluster Health/YAML/*',
           'Cluster Physical Interfaces/CSV/*',
           'Cluster Physical Interfaces/HTML/*',
           'Cluster Physical Interfaces/JSON/*',
           'Cluster Physical Interfaces/Markdown/*',
           'Cluster Physical Interfaces/Mindmap/*',
           'Cluster Physical Interfaces/YAML/*',
           'Cluster RS Member Interfaces/CSV/*',
           'Cluster RS Member Interfaces/HTML/*',
           'Cluster RS Member Interfaces/JSON/*',
           'Cluster RS Member Interfaces/Markdown/*',
           'Cluster RS Member Interfaces/Mindmap/*',
           'Cluster RS Member Interfaces/YAML/*',
           'Compute Controllers/CSV/*',
           'Compute Controllers/HTML/*',
           'Compute Controllers/JSON/*',
           'Compute Controllers/Markdown/*',
           'Compute Controllers/Mindmap/*',
           'Compute Controllers/YAML/*',
           'Compute Domains/CSV/*',
           'Compute Domains/HTML/*',
           'Compute Domains/JSON/*',
           'Compute Domains/Markdown/*',
           'Compute Domains/Mindmap/*',
           'Compute Domains/YAML/*',
           'Compute Endpoint Policy Descriptions/CSV/*',
           'Compute Endpoint Policy Descriptions/HTML/*',
           'Compute Endpoint Policy Descriptions/JSON/*',
           'Compute Endpoint Policy Descriptions/Markdown/*',
           'Compute Endpoint Policy Descriptions/Mindmap/*',
           'Compute Endpoint Policy Descriptions/YAML/*',
           'Compute Providers/CSV/*',
           'Compute Providers/HTML/*',
           'Compute Providers/JSON/*',
           'Compute Providers/Markdown/*',
           'Compute Providers/Mindmap/*',
           'Compute Providers/YAML/*',
           'Compute RS Domain Policies/CSV/*',
           'Compute RS Domain Policies/HTML/*',
           'Compute RS Domain Policies/JSON/*',
           'Compute RS Domain Policies/Markdown/*',
           'Compute RS Domain Policies/Mindmap/*',
           'Compute RS Domain Policies/YAML/*',
           'Context Source Relationships/CSV/*',
           'Context Source Relationships/HTML/*',
           'Context Source Relationships/JSON/*',
           'Context Source Relationships/Markdown/*',
           'Context Source Relationships/Mindmap/*',
           'Context Source Relationships/YAML/*',
           'Contexts Target Relationships/CSV/*',
           'Contexts Target Relationships/HTML/*',
           'Contexts Target Relationships/JSON/*',
           'Contexts Target Relationships/Markdown/*',
           'Contexts Target Relationships/Mindmap/*',
           'Contexts Target Relationships/YAML/*',
           'Contexts/CSV/*',
           'Contexts/HTML/*',
           'Contexts/JSON/*',
           'Contexts/Markdown/*',
           'Contexts/Mindmap/*',
           'Contexts/YAML/*',
           'Contract Consumer Interfaces/CSV/*',
           'Contract Consumer Interfaces/HTML/*',
           'Contract Consumer Interfaces/JSON/*',
           'Contract Consumer Interfaces/Markdown/*',
           'Contract Consumer Interfaces/Mindmap/*',
           'Contract Consumer Interfaces/YAML/*',
           'Contract Consumers/CSV/*',
           'Contract Consumers/HTML/*',
           'Contract Consumers/JSON/*',
           'Contract Consumers/Markdown/*',
           'Contract Consumers/Mindmap/*',
           'Contract Consumers/YAML/*',
           'Contract Providers/CSV/*',
           'Contract Providers/HTML/*',
           'Contract Providers/JSON/*',
           'Contract Providers/Markdown/*',
           'Contract Providers/Mindmap/*',
           'Contract Providers/YAML/*',
           'Contract Subjects/CSV/*',
           'Contract Subjects/HTML/*',
           'Contract Subjects/JSON/*',
           'Contract Subjects/Markdown/*',
           'Contract Subjects/Mindmap/*',
           'Contract Subjects/YAML/*',
           'Contracts/CSV/*',
           'Contracts/HTML/*',
           'Contracts/JSON/*',
           'Contracts/Markdown/*',
           'Contracts/Mindmap/*',
           'Contracts/YAML/*',
           'Controllers/CSV/*',
           'Controllers/HTML/*',
           'Controllers/JSON/*',
           'Controllers/Markdown/*',
           'Controllers/Mindmap/*',
           'Controllers/YAML/*',
           'Device Packages/CSV/*',
           'Device Packages/HTML/*',
           'Device Packages/JSON/*',
           'Device Packages/Markdown/*',
           'Device Packages/Mindmap/*',
           'Device Packages/YAML/*',
           'Domain Attachments/CSV/*',
           'Domain Attachments/HTML/*',
           'Domain Attachments/JSON/*',
           'Domain Attachments/Markdown/*',
           'Domain Attachments/Mindmap/*',
           'Domain Attachments/YAML/*',
           'Domain Profile Source Relationships/CSV/*',
           'Domain Profile Source Relationships/HTML/*',
           'Domain Profile Source Relationships/JSON/*',
           'Domain Profile Source Relationships/Markdown/*',
           'Domain Profile Source Relationships/Mindmap/*',
           'Domain Profile Source Relationships/YAML/*',
           'EPG Bridge Domain Links/CSV/*',
           'EPG Bridge Domain Links/HTML/*',
           'EPG Bridge Domain Links/JSON/*',
           'EPG Bridge Domain Links/Markdown/*',
           'EPG Bridge Domain Links/Mindmap/*',
           'EPG Bridge Domain Links/YAML/*',
           'EPGs/CSV/*',
           'EPGs/HTML/*',
           'EPGs/JSON/*',
           'EPGs/Markdown/*',
           'EPGs/Mindmap/*',
           'EPGs/YAML/*',
           'Endpoint Profile Containers/CSV/*',
           'Endpoint Profile Containers/HTML/*',
           'Endpoint Profile Containers/JSON/*',
           'Endpoint Profile Containers/Markdown/*',
           'Endpoint Profile Containers/Mindmap/*',
           'Endpoint Profile Containers/YAML/*',
           'Endpoints To Paths/CSV/*',
           'Endpoints To Paths/HTML/*',
           'Endpoints To Paths/JSON/*',
           'Endpoints To Paths/Markdown/*',
           'Endpoints To Paths/Mindmap/*',
           'Endpoints To Paths/YAML/*',
           'Endpoints/CSV/*',
           'Endpoints/HTML/*',
           'Endpoints/JSON/*',
           'Endpoints/Markdown/*',
           'Endpoints/Mindmap/*',
           'Endpoints/YAML/*',
           'Equipment Board Slots/CSV/*',
           'Equipment Board Slots/HTML/*',
           'Equipment Board Slots/JSON/*',
           'Equipment Board Slots/Markdown/*',
           'Equipment Board Slots/Mindmap/*',
           'Equipment Board Slots/YAML/*',
           'Equipment Boards/CSV/*',
           'Equipment Boards/HTML/*',
           'Equipment Boards/JSON/*',
           'Equipment Boards/Markdown/*',
           'Equipment Boards/Mindmap/*',
           'Equipment Boards/YAML/*',
           'Equipment CPUs/CSV/*',
           'Equipment CPUs/HTML/*',
           'Equipment CPUs/JSON/*',
           'Equipment CPUs/Markdown/*',
           'Equipment CPUs/Mindmap/*',
           'Equipment CPUs/YAML/*',
           'Equipment Chassis/CSV/*',
           'Equipment Chassis/HTML/*',
           'Equipment Chassis/JSON/*',
           'Equipment Chassis/Markdown/*',
           'Equipment Chassis/Mindmap/*',
           'Equipment Chassis/YAML/*',
           'Equipment DIMMs/CSV/*',
           'Equipment DIMMs/HTML/*',
           'Equipment DIMMs/JSON/*',
           'Equipment DIMMs/Markdown/*',
           'Equipment DIMMs/Mindmap/*',
           'Equipment DIMMs/YAML/*',
           'Equipment Fabric Extenders/CSV/*',
           'Equipment Fabric Extenders/HTML/*',
           'Equipment Fabric Extenders/JSON/*',
           'Equipment Fabric Extenders/Markdown/*',
           'Equipment Fabric Extenders/Mindmap/*',
           'Equipment Fabric Extenders/YAML/*',
           'Equipment Fabric Ports/CSV/*',
           'Equipment Fabric Ports/HTML/*',
           'Equipment Fabric Ports/JSON/*',
           'Equipment Fabric Ports/Markdown/*',
           'Equipment Fabric Ports/Mindmap/*',
           'Equipment Fabric Ports/YAML/*',
           'Equipment Fan Tray Slots/CSV/*',
           'Equipment Fan Tray Slots/HTML/*',
           'Equipment Fan Tray Slots/JSON/*',
           'Equipment Fan Tray Slots/Markdown/*',
           'Equipment Fan Tray Slots/Mindmap/*',
           'Equipment Fan Tray Slots/YAML/*',
           'Equipment Fan Trays/CSV/*',
           'Equipment Fan Trays/HTML/*',
           'Equipment Fan Trays/JSON/*',
           'Equipment Fan Trays/Markdown/*',
           'Equipment Fan Trays/Mindmap/*',
           'Equipment Fan Trays/YAML/*',
           'Equipment Fans/CSV/*',
           'Equipment Fans/HTML/*',
           'Equipment Fans/JSON/*',
           'Equipment Fans/Markdown/*',
           'Equipment Fans/Mindmap/*',
           'Equipment Fans/YAML/*',
           'Equipment Field Programmable Gate Arrays/CSV/*',
           'Equipment Field Programmable Gate Arrays/HTML/*',
           'Equipment Field Programmable Gate Arrays/JSON/*',
           'Equipment Field Programmable Gate Arrays/Markdown/*',
           'Equipment Field Programmable Gate Arrays/Mindmap/*',
           'Equipment Field Programmable Gate Arrays/YAML/*',
           'Equipment Indicator LEDs/CSV/*',
           'Equipment Indicator LEDs/HTML/*',
           'Equipment Indicator LEDs/JSON/*',
           'Equipment Indicator LEDs/Markdown/*',
           'Equipment Indicator LEDs/Mindmap/*',
           'Equipment Indicator LEDs/YAML/*',
           'Equipment Leaf Ports/CSV/*',
           'Equipment Leaf Ports/HTML/*',
           'Equipment Leaf Ports/JSON/*',
           'Equipment Leaf Ports/Markdown/*',
           'Equipment Leaf Ports/Mindmap/*',
           'Equipment Leaf Ports/YAML/*',
           'Equipment Line Card Slots/CSV/*',
           'Equipment Line Card Slots/HTML/*',
           'Equipment Line Card Slots/JSON/*',
           'Equipment Line Card Slots/Markdown/*',
           'Equipment Line Card Slots/Mindmap/*',
           'Equipment Line Card Slots/YAML/*',
           'Equipment Line Cards/CSV/*',
           'Equipment Line Cards/HTML/*',
           'Equipment Line Cards/JSON/*',
           'Equipment Line Cards/Markdown/*',
           'Equipment Line Cards/Mindmap/*',
           'Equipment Line Cards/YAML/*',
           'Equipment Port Locator LEDs/CSV/*',
           'Equipment Port Locator LEDs/HTML/*',
           'Equipment Port Locator LEDs/JSON/*',
           'Equipment Port Locator LEDs/Markdown/*',
           'Equipment Port Locator LEDs/Mindmap/*',
           'Equipment Port Locator LEDs/YAML/*',
           'Equipment Power Supplies/CSV/*',
           'Equipment Power Supplies/HTML/*',
           'Equipment Power Supplies/JSON/*',
           'Equipment Power Supplies/Markdown/*',
           'Equipment Power Supplies/Mindmap/*',
           'Equipment Power Supplies/YAML/*',
           'Equipment Power Supply Slots/CSV/*',
           'Equipment Power Supply Slots/HTML/*',
           'Equipment Power Supply Slots/JSON/*',
           'Equipment Power Supply Slots/Markdown/*',
           'Equipment Power Supply Slots/Mindmap/*',
           'Equipment Power Supply Slots/YAML/*',
           'Equipment RS IO Port Physical Configs/CSV/*',
           'Equipment RS IO Port Physical Configs/HTML/*',
           'Equipment RS IO Port Physical Configs/JSON/*',
           'Equipment RS IO Port Physical Configs/Markdown/*',
           'Equipment RS IO Port Physical Configs/Mindmap/*',
           'Equipment RS IO Port Physical Configs/YAML/*',
           'Equipment SP Common Blocks/CSV/*',
           'Equipment SP Common Blocks/HTML/*',
           'Equipment SP Common Blocks/JSON/*',
           'Equipment SP Common Blocks/Markdown/*',
           'Equipment SP Common Blocks/Mindmap/*',
           'Equipment SP Common Blocks/YAML/*',
           'Equipment SPROM LCs/CSV/*',
           'Equipment SPROM LCs/HTML/*',
           'Equipment SPROM LCs/JSON/*',
           'Equipment SPROM LCs/Markdown/*',
           'Equipment SPROM LCs/Mindmap/*',
           'Equipment SPROM LCs/YAML/*',
           'Equipment SPROM Power Supplies/CSV/*',
           'Equipment SPROM Power Supplies/HTML/*',
           'Equipment SPROM Power Supplies/JSON/*',
           'Equipment SPROM Power Supplies/Markdown/*',
           'Equipment SPROM Power Supplies/Mindmap/*',
           'Equipment SPROM Power Supplies/YAML/*',
           'Equipment SPROM Power Supply Blocks/CSV/*',
           'Equipment SPROM Power Supply Blocks/HTML/*',
           'Equipment SPROM Power Supply Blocks/JSON/*',
           'Equipment SPROM Power Supply Blocks/Markdown/*',
           'Equipment SPROM Power Supply Blocks/Mindmap/*',
           'Equipment SPROM Power Supply Blocks/YAML/*',
           'Equipment SPROM Supervisors/CSV/*',
           'Equipment SPROM Supervisors/HTML/*',
           'Equipment SPROM Supervisors/JSON/*',
           'Equipment SPROM Supervisors/Markdown/*',
           'Equipment SPROM Supervisors/Mindmap/*',
           'Equipment SPROM Supervisors/YAML/*',
           'Equipment Sensors/CSV/*',
           'Equipment Sensors/HTML/*',
           'Equipment Sensors/JSON/*',
           'Equipment Sensors/Markdown/*',
           'Equipment Sensors/Mindmap/*',
           'Equipment Sensors/YAML/*',
           'Equipment Storage/CSV/*',
           'Equipment Storage/HTML/*',
           'Equipment Storage/JSON/*',
           'Equipment Storage/Markdown/*',
           'Equipment Storage/Mindmap/*',
           'Equipment Storage/YAML/*',
           'Equipment Supervisor Slots/CSV/*',
           'Equipment Supervisor Slots/HTML/*',
           'Equipment Supervisor Slots/JSON/*',
           'Equipment Supervisor Slots/Markdown/*',
           'Equipment Supervisor Slots/Mindmap/*',
           'Equipment Supervisor Slots/YAML/*',
           'Equipment Supervisors/CSV/*',
           'Equipment Supervisors/HTML/*',
           'Equipment Supervisors/JSON/*',
           'Equipment Supervisors/Markdown/*',
           'Equipment Supervisors/Mindmap/*',
           'Equipment Supervisors/YAML/*',
           'Ethernet Port Manager Physical Interfaces/CSV/*',
           'Ethernet Port Manager Physical Interfaces/HTML/*',
           'Ethernet Port Manager Physical Interfaces/JSON/*',
           'Ethernet Port Manager Physical Interfaces/Markdown/*',
           'Ethernet Port Manager Physical Interfaces/Mindmap/*',
           'Ethernet Port Manager Physical Interfaces/YAML/*',
           'Events/CSV/*',
           'Events/HTML/*',
           'Events/JSON/*',
           'Events/Markdown/*',
           'Events/Mindmap/*',
           'Events/YAML/*',
           'FEX Policies/CSV/*',
           'FEX Policies/HTML/*',
           'FEX Policies/JSON/*',
           'FEX Policies/Markdown/*',
           'FEX Policies/Mindmap/*',
           'FEX Policies/YAML/*',
           'Fabric Extended Path Endpoint Containers/CSV/*',
           'Fabric Extended Path Endpoint Containers/HTML/*',
           'Fabric Extended Path Endpoint Containers/JSON/*',
           'Fabric Extended Path Endpoint Containers/Markdown/*',
           'Fabric Extended Path Endpoint Containers/Mindmap/*',
           'Fabric Extended Path Endpoint Containers/YAML/*',
           'Fabric Instances/CSV/*',
           'Fabric Instances/HTML/*',
           'Fabric Instances/JSON/*',
           'Fabric Instances/Markdown/*',
           'Fabric Instances/Mindmap/*',
           'Fabric Instances/YAML/*',
           'Fabric Link Containers/CSV/*',
           'Fabric Link Containers/HTML/*',
           'Fabric Link Containers/JSON/*',
           'Fabric Link Containers/Markdown/*',
           'Fabric Link Containers/Mindmap/*',
           'Fabric Link Containers/YAML/*',
           'Fabric Links/CSV/*',
           'Fabric Links/HTML/*',
           'Fabric Links/JSON/*',
           'Fabric Links/Markdown/*',
           'Fabric Links/Mindmap/*',
           'Fabric Links/YAML/*',
           'Fabric Loose Links/CSV/*',
           'Fabric Loose Links/HTML/*',
           'Fabric Loose Links/JSON/*',
           'Fabric Loose Links/Markdown/*',
           'Fabric Loose Links/Mindmap/*',
           'Fabric Loose Links/YAML/*',
           'Fabric Loose Nodes/CSV/*',
           'Fabric Loose Nodes/HTML/*',
           'Fabric Loose Nodes/JSON/*',
           'Fabric Loose Nodes/Markdown/*',
           'Fabric Loose Nodes/Mindmap/*',
           'Fabric Loose Nodes/YAML/*',
           'Fabric Membership/CSV/*',
           'Fabric Membership/HTML/*',
           'Fabric Membership/JSON/*',
           'Fabric Membership/Markdown/*',
           'Fabric Membership/Mindmap/*',
           'Fabric Membership/YAML/*',
           'Fabric Nodes/CSV/*',
           'Fabric Nodes/HTML/*',
           'Fabric Nodes/JSON/*',
           'Fabric Nodes/Markdown/*',
           'Fabric Nodes/Mindmap/*',
           'Fabric Nodes/YAML/*',
           'Fabric Path Endpoint Containers/CSV/*',
           'Fabric Path Endpoint Containers/HTML/*',
           'Fabric Path Endpoint Containers/JSON/*',
           'Fabric Path Endpoint Containers/Markdown/*',
           'Fabric Path Endpoint Containers/Mindmap/*',
           'Fabric Path Endpoint Containers/YAML/*',
           'Fabric Path Endpoints/CSV/*',
           'Fabric Path Endpoints/HTML/*',
           'Fabric Path Endpoints/JSON/*',
           'Fabric Path Endpoints/Markdown/*',
           'Fabric Path Endpoints/Mindmap/*',
           'Fabric Path Endpoints/YAML/*',
           'Fabric Paths/CSV/*',
           'Fabric Paths/HTML/*',
           'Fabric Paths/JSON/*',
           'Fabric Paths/Markdown/*',
           'Fabric Paths/Mindmap/*',
           'Fabric Paths/YAML/*',
           'Fabric Pods/CSV/*',
           'Fabric Pods/HTML/*',
           'Fabric Pods/JSON/*',
           'Fabric Pods/Markdown/*',
           'Fabric Pods/Mindmap/*',
           'Fabric Pods/YAML/*',
           'Fabric Protected Path Endpoint Containers/CSV/*',
           'Fabric Protected Path Endpoint Containers/HTML/*',
           'Fabric Protected Path Endpoint Containers/JSON/*',
           'Fabric Protected Path Endpoint Containers/Markdown/*',
           'Fabric Protected Path Endpoint Containers/Mindmap/*',
           'Fabric Protected Path Endpoint Containers/YAML/*',
           'Fault Summary/CSV/*',
           'Fault Summary/HTML/*',
           'Fault Summary/JSON/*',
           'Fault Summary/Markdown/*',
           'Fault Summary/Mindmap/*',
           'Fault Summary/YAML/*',
           'Fibre Channel Entities/CSV/*',
           'Fibre Channel Entities/HTML/*',
           'Fibre Channel Entities/JSON/*',
           'Fibre Channel Entities/Markdown/*',
           'Fibre Channel Entities/Mindmap/*',
           'Fibre Channel Entities/YAML/*',
           'Filters/CSV/*',
           'Filters/HTML/*',
           'Filters/JSON/*',
           'Filters/Markdown/*',
           'Filters/Mindmap/*',
           'Filters/YAML/*',
           'Firmware Card Running/CSV/*',
           'Firmware Card Running/HTML/*',
           'Firmware Card Running/JSON/*',
           'Firmware Card Running/Markdown/*',
           'Firmware Card Running/Mindmap/*',
           'Firmware Card Running/YAML/*',
           'Firmware Compute Running/CSV/*',
           'Firmware Compute Running/HTML/*',
           'Firmware Compute Running/JSON/*',
           'Firmware Compute Running/Markdown/*',
           'Firmware Compute Running/Mindmap/*',
           'Firmware Compute Running/YAML/*',
           'Firmware Running/CSV/*',
           'Firmware Running/HTML/*',
           'Firmware Running/JSON/*',
           'Firmware Running/Markdown/*',
           'Firmware Running/Mindmap/*',
           'Firmware Running/YAML/*',
           'Function Policies/CSV/*',
           'Function Policies/HTML/*',
           'Function Policies/JSON/*',
           'Function Policies/Markdown/*',
           'Function Policies/Mindmap/*',
           'Function Policies/YAML/*',
           'Health/CSV/*',
           'Health/HTML/*',
           'Health/JSON/*',
           'Health/Markdown/*',
           'Health/Mindmap/*',
           'Health/YAML/*',
           'Host Port Selectors/CSV/*',
           'Host Port Selectors/HTML/*',
           'Host Port Selectors/JSON/*',
           'Host Port Selectors/Markdown/*',
           'Host Port Selectors/Mindmap/*',
           'Host Port Selectors/YAML/*',
           'IP Addresses/CSV/*',
           'IP Addresses/HTML/*',
           'IP Addresses/JSON/*',
           'IP Addresses/Markdown/*',
           'IP Addresses/Mindmap/*',
           'IP Addresses/YAML/*',
           'IPv4 Addresses/CSV/*',
           'IPv4 Addresses/HTML/*',
           'IPv4 Addresses/JSON/*',
           'IPv4 Addresses/Markdown/*',
           'IPv4 Addresses/Mindmap/*',
           'IPv4 Addresses/YAML/*',
           'IPv4 Domains/CSV/*',
           'IPv4 Domains/HTML/*',
           'IPv4 Domains/JSON/*',
           'IPv4 Domains/Markdown/*',
           'IPv4 Domains/Mindmap/*',
           'IPv4 Domains/YAML/*',
           'IPv4 Entities/CSV/*',
           'IPv4 Entities/HTML/*',
           'IPv4 Entities/JSON/*',
           'IPv4 Entities/Markdown/*',
           'IPv4 Entities/Mindmap/*',
           'IPv4 Entities/YAML/*',
           'IPv4 Instances/CSV/*',
           'IPv4 Instances/HTML/*',
           'IPv4 Instances/JSON/*',
           'IPv4 Instances/Markdown/*',
           'IPv4 Instances/Mindmap/*',
           'IPv4 Instances/YAML/*',
           'IPv4 Interfaces/CSV/*',
           'IPv4 Interfaces/HTML/*',
           'IPv4 Interfaces/JSON/*',
           'IPv4 Interfaces/Markdown/*',
           'IPv4 Interfaces/Mindmap/*',
           'IPv4 Interfaces/YAML/*',
           'IPv4 Next Hop/CSV/*',
           'IPv4 Next Hop/HTML/*',
           'IPv4 Next Hop/JSON/*',
           'IPv4 Next Hop/Markdown/*',
           'IPv4 Next Hop/Mindmap/*',
           'IPv4 Next Hop/YAML/*',
           'IPv4 Routes/CSV/*',
           'IPv4 Routes/HTML/*',
           'IPv4 Routes/JSON/*',
           'IPv4 Routes/Markdown/*',
           'IPv4 Routes/Mindmap/*',
           'IPv4 Routes/YAML/*',
           'ISIS Adjacency Endpoints/CSV/*',
           'ISIS Adjacency Endpoints/HTML/*',
           'ISIS Adjacency Endpoints/JSON/*',
           'ISIS Adjacency Endpoints/Markdown/*',
           'ISIS Adjacency Endpoints/Mindmap/*',
           'ISIS Adjacency Endpoints/YAML/*',
           'ISIS Discovered Tunnel Endpoints/CSV/*',
           'ISIS Discovered Tunnel Endpoints/HTML/*',
           'ISIS Discovered Tunnel Endpoints/JSON/*',
           'ISIS Discovered Tunnel Endpoints/Markdown/*',
           'ISIS Discovered Tunnel Endpoints/Mindmap/*',
           'ISIS Discovered Tunnel Endpoints/YAML/*',
           'ISIS Domains Level/CSV/*',
           'ISIS Domains Level/HTML/*',
           'ISIS Domains Level/JSON/*',
           'ISIS Domains Level/Markdown/*',
           'ISIS Domains Level/Mindmap/*',
           'ISIS Domains Level/YAML/*',
           'ISIS Domains/CSV/*',
           'ISIS Domains/HTML/*',
           'ISIS Domains/JSON/*',
           'ISIS Domains/Markdown/*',
           'ISIS Domains/Mindmap/*',
           'ISIS Domains/YAML/*',
           'ISIS Entities/CSV/*',
           'ISIS Entities/HTML/*',
           'ISIS Entities/JSON/*',
           'ISIS Entities/Markdown/*',
           'ISIS Entities/Mindmap/*',
           'ISIS Entities/YAML/*',
           'ISIS Instances/CSV/*',
           'ISIS Instances/HTML/*',
           'ISIS Instances/JSON/*',
           'ISIS Instances/Markdown/*',
           'ISIS Instances/Mindmap/*',
           'ISIS Instances/YAML/*',
           'ISIS Interfaces Level/CSV/*',
           'ISIS Interfaces Level/HTML/*',
           'ISIS Interfaces Level/JSON/*',
           'ISIS Interfaces Level/Markdown/*',
           'ISIS Interfaces Level/Mindmap/*',
           'ISIS Interfaces Level/YAML/*',
           'ISIS Interfaces/CSV/*',
           'ISIS Interfaces/HTML/*',
           'ISIS Interfaces/JSON/*',
           'ISIS Interfaces/Markdown/*',
           'ISIS Interfaces/Mindmap/*',
           'ISIS Interfaces/YAML/*',
           'ISIS Next Hop/CSV/*',
           'ISIS Next Hop/HTML/*',
           'ISIS Next Hop/JSON/*',
           'ISIS Next Hop/Markdown/*',
           'ISIS Next Hop/Mindmap/*',
           'ISIS Next Hop/YAML/*',
           'ISIS Routes/CSV/*',
           'ISIS Routes/HTML/*',
           'ISIS Routes/JSON/*',
           'ISIS Routes/Markdown/*',
           'ISIS Routes/Mindmap/*',
           'ISIS Routes/YAML/*',
           'Interface Policies/CSV/*',
           'Interface Policies/HTML/*',
           'Interface Policies/JSON/*',
           'Interface Policies/Markdown/*',
           'Interface Policies/Mindmap/*',
           'Interface Policies/YAML/*',
           'Interface Profiles/CSV/*',
           'Interface Profiles/HTML/*',
           'Interface Profiles/JSON/*',
           'Interface Profiles/Markdown/*',
           'Interface Profiles/Mindmap/*',
           'Interface Profiles/YAML/*',
           'L2 Bridge Domains/CSV/*',
           'L2 Bridge Domains/HTML/*',
           'L2 Bridge Domains/JSON/*',
           'L2 Bridge Domains/Markdown/*',
           'L2 Bridge Domains/Mindmap/*',
           'L2 Bridge Domains/YAML/*',
           'L2 EPG Bridge Domain Source Relationships/CSV/*',
           'L2 EPG Bridge Domain Source Relationships/HTML/*',
           'L2 EPG Bridge Domain Source Relationships/JSON/*',
           'L2 EPG Bridge Domain Source Relationships/Markdown/*',
           'L2 EPG Bridge Domain Source Relationships/Mindmap/*',
           'L2 EPG Bridge Domain Source Relationships/YAML/*',
           'L2 External Instance Profiles/CSV/*',
           'L2 External Instance Profiles/HTML/*',
           'L2 External Instance Profiles/JSON/*',
           'L2 External Instance Profiles/Markdown/*',
           'L2 External Instance Profiles/Mindmap/*',
           'L2 External Instance Profiles/YAML/*',
           'L2 External Interfaces/CSV/*',
           'L2 External Interfaces/HTML/*',
           'L2 External Interfaces/JSON/*',
           'L2 External Interfaces/Markdown/*',
           'L2 External Interfaces/Mindmap/*',
           'L2 External Interfaces/YAML/*',
           'L2 External Logical Interface Profiles/CSV/*',
           'L2 External Logical Interface Profiles/HTML/*',
           'L2 External Logical Interface Profiles/JSON/*',
           'L2 External Logical Interface Profiles/Markdown/*',
           'L2 External Logical Interface Profiles/Mindmap/*',
           'L2 External Logical Interface Profiles/YAML/*',
           'L2 External Logical Node Profiles/CSV/*',
           'L2 External Logical Node Profiles/HTML/*',
           'L2 External Logical Node Profiles/JSON/*',
           'L2 External Logical Node Profiles/Markdown/*',
           'L2 External Logical Node Profiles/Mindmap/*',
           'L2 External Logical Node Profiles/YAML/*',
           'L2Out Paths/CSV/*',
           'L2Out Paths/HTML/*',
           'L2Out Paths/JSON/*',
           'L2Out Paths/Markdown/*',
           'L2Out Paths/Mindmap/*',
           'L2Out Paths/YAML/*',
           'L2Outs/CSV/*',
           'L2Outs/HTML/*',
           'L2Outs/JSON/*',
           'L2Outs/Markdown/*',
           'L2Outs/Mindmap/*',
           'L2Outs/YAML/*',
           'L3 Contexts Source Relationships/CSV/*',
           'L3 Contexts Source Relationships/HTML/*',
           'L3 Contexts Source Relationships/JSON/*',
           'L3 Contexts Source Relationships/Markdown/*',
           'L3 Contexts Source Relationships/Mindmap/*',
           'L3 Contexts Source Relationships/YAML/*',
           'L3 Contexts/CSV/*',
           'L3 Contexts/HTML/*',
           'L3 Contexts/JSON/*',
           'L3 Contexts/Markdown/*',
           'L3 Contexts/Mindmap/*',
           'L3 Contexts/YAML/*',
           'L3 Domains Source Relationships/CSV/*',
           'L3 Domains Source Relationships/HTML/*',
           'L3 Domains Source Relationships/JSON/*',
           'L3 Domains Source Relationships/Markdown/*',
           'L3 Domains Source Relationships/Mindmap/*',
           'L3 Domains Source Relationships/YAML/*',
           'L3 Domains/CSV/*',
           'L3 Domains/HTML/*',
           'L3 Domains/JSON/*',
           'L3 Domains/Markdown/*',
           'L3 Domains/Mindmap/*',
           'L3 Domains/YAML/*',
           'L3 Instances/CSV/*',
           'L3 Instances/HTML/*',
           'L3 Instances/JSON/*',
           'L3 Instances/Markdown/*',
           'L3 Instances/Mindmap/*',
           'L3 Instances/YAML/*',
           'L3 Interfaces/CSV/*',
           'L3 Interfaces/HTML/*',
           'L3 Interfaces/JSON/*',
           'L3 Interfaces/Markdown/*',
           'L3 Interfaces/Mindmap/*',
           'L3 Interfaces/YAML/*',
           'L3 Logical Interface Profiles/CSV/*',
           'L3 Logical Interface Profiles/HTML/*',
           'L3 Logical Interface Profiles/JSON/*',
           'L3 Logical Interface Profiles/Markdown/*',
           'L3 Logical Interface Profiles/Mindmap/*',
           'L3 Logical Interface Profiles/YAML/*',
           'L3 Logical Node Profiles/CSV/*',
           'L3 Logical Node Profiles/HTML/*',
           'L3 Logical Node Profiles/JSON/*',
           'L3 Logical Node Profiles/Markdown/*',
           'L3 Logical Node Profiles/Mindmap/*',
           'L3 Logical Node Profiles/YAML/*',
           'L3 Physical Interface Source Relationships/CSV/*',
           'L3 Physical Interface Source Relationships/HTML/*',
           'L3 Physical Interface Source Relationships/JSON/*',
           'L3 Physical Interface Source Relationships/Markdown/*',
           'L3 Physical Interface Source Relationships/Mindmap/*',
           'L3 Physical Interface Source Relationships/YAML/*',
           'L3 Routed Interfaces/CSV/*',
           'L3 Routed Interfaces/HTML/*',
           'L3 Routed Interfaces/JSON/*',
           'L3 Routed Interfaces/Markdown/*',
           'L3 Routed Interfaces/Mindmap/*',
           'L3 Routed Interfaces/YAML/*',
           'L3 Routed Loopback Interfaces/CSV/*',
           'L3 Routed Loopback Interfaces/HTML/*',
           'L3 Routed Loopback Interfaces/JSON/*',
           'L3 Routed Loopback Interfaces/Markdown/*',
           'L3 Routed Loopback Interfaces/Mindmap/*',
           'L3 Routed Loopback Interfaces/YAML/*',
           'L3 Subinterfaces/CSV/*',
           'L3 Subinterfaces/HTML/*',
           'L3 Subinterfaces/JSON/*',
           'L3 Subinterfaces/Markdown/*',
           'L3 Subinterfaces/Mindmap/*',
           'L3 Subinterfaces/YAML/*',
           'L3 Subnets/CSV/*',
           'L3 Subnets/HTML/*',
           'L3 Subnets/JSON/*',
           'L3 Subnets/Markdown/*',
           'L3 Subnets/Mindmap/*',
           'L3 Subnets/YAML/*',
           'L3Out IP Addresses/CSV/*',
           'L3Out IP Addresses/HTML/*',
           'L3Out IP Addresses/JSON/*',
           'L3Out IP Addresses/Markdown/*',
           'L3Out IP Addresses/Mindmap/*',
           'L3Out IP Addresses/YAML/*',
           'L3Out Members/CSV/*',
           'L3Out Members/HTML/*',
           'L3Out Members/JSON/*',
           'L3Out Members/Markdown/*',
           'L3Out Members/Mindmap/*',
           'L3Out Members/YAML/*',
           'L3Out Node Source Relationships/CSV/*',
           'L3Out Node Source Relationships/HTML/*',
           'L3Out Node Source Relationships/JSON/*',
           'L3Out Node Source Relationships/Markdown/*',
           'L3Out Node Source Relationships/Mindmap/*',
           'L3Out Node Source Relationships/YAML/*',
           'L3Out Path Source Relationships/CSV/*',
           'L3Out Path Source Relationships/HTML/*',
           'L3Out Path Source Relationships/JSON/*',
           'L3Out Path Source Relationships/Markdown/*',
           'L3Out Path Source Relationships/Mindmap/*',
           'L3Out Path Source Relationships/YAML/*',
           'L3Out Profiles/CSV/*',
           'L3Out Profiles/HTML/*',
           'L3Out Profiles/JSON/*',
           'L3Out Profiles/Markdown/*',
           'L3Out Profiles/Mindmap/*',
           'L3Out Profiles/YAML/*',
           'L3Outs/CSV/*',
           'L3Outs/HTML/*',
           'L3Outs/JSON/*',
           'L3Outs/Markdown/*',
           'L3Outs/Mindmap/*',
           'L3Outs/YAML/*',
           'Leaf Interface Profiles/CSV/*',
           'Leaf Interface Profiles/HTML/*',
           'Leaf Interface Profiles/JSON/*',
           'Leaf Interface Profiles/Markdown/*',
           'Leaf Interface Profiles/Mindmap/*',
           'Leaf Interface Profiles/YAML/*',
           'Leaf Switch Profiles/CSV/*',
           'Leaf Switch Profiles/HTML/*',
           'Leaf Switch Profiles/JSON/*',
           'Leaf Switch Profiles/Markdown/*',
           'Leaf Switch Profiles/Mindmap/*',
           'Leaf Switch Profiles/YAML/*',
           'License Entitlements/CSV/*',
           'License Entitlements/HTML/*',
           'License Entitlements/JSON/*',
           'License Entitlements/Markdown/*',
           'License Entitlements/Mindmap/*',
           'License Entitlements/YAML/*',
           'Locales/CSV/*',
           'Locales/HTML/*',
           'Locales/JSON/*',
           'Locales/Markdown/*',
           'Locales/Mindmap/*',
           'Locales/YAML/*',
           'Path Attachments/CSV/*',
           'Path Attachments/HTML/*',
           'Path Attachments/JSON/*',
           'Path Attachments/Markdown/*',
           'Path Attachments/Mindmap/*',
           'Path Attachments/YAML/*',
           'Physical Domains/CSV/*',
           'Physical Domains/HTML/*',
           'Physical Domains/JSON/*',
           'Physical Domains/Markdown/*',
           'Physical Domains/Mindmap/*',
           'Physical Domains/YAML/*',
           'Physical Interfaces/CSV/*',
           'Physical Interfaces/HTML/*',
           'Physical Interfaces/JSON/*',
           'Physical Interfaces/Markdown/*',
           'Physical Interfaces/Mindmap/*',
           'Physical Interfaces/YAML/*',
           'Port Blocks/CSV/*',
           'Port Blocks/HTML/*',
           'Port Blocks/JSON/*',
           'Port Blocks/Markdown/*',
           'Port Blocks/Mindmap/*',
           'Port Blocks/YAML/*',
           'Prefix List Detailed/CSV/*',
           'Prefix List Detailed/HTML/*',
           'Prefix List Detailed/JSON/*',
           'Prefix List Detailed/Markdown/*',
           'Prefix List Detailed/Mindmap/*',
           'Prefix List Detailed/YAML/*',
           'Prefix List/CSV/*',
           'Prefix List/HTML/*',
           'Prefix List/JSON/*',
           'Prefix List/Markdown/*',
           'Prefix List/Mindmap/*',
           'Prefix List/YAML/*',
           'QOS Classes/CSV/*',
           'QOS Classes/HTML/*',
           'QOS Classes/JSON/*',
           'QOS Classes/Markdown/*',
           'QOS Classes/Mindmap/*',
           'QOS Classes/YAML/*',
           'Route Policies/CSV/*',
           'Route Policies/HTML/*',
           'Route Policies/JSON/*',
           'Route Policies/Markdown/*',
           'Route Policies/Mindmap/*',
           'Route Policies/YAML/*',
           'Security Domains/CSV/*',
           'Security Domains/HTML/*',
           'Security Domains/JSON/*',
           'Security Domains/Markdown/*',
           'Security Domains/Mindmap/*',
           'Security Domains/YAML/*',
           'Spine Access Policy Groups/CSV/*',
           'Spine Access Policy Groups/HTML/*',
           'Spine Access Policy Groups/JSON/*',
           'Spine Access Policy Groups/Markdown/*',
           'Spine Access Policy Groups/Mindmap/*',
           'Spine Access Policy Groups/YAML/*',
           'Spine Access Port Profiles/CSV/*',
           'Spine Access Port Profiles/HTML/*',
           'Spine Access Port Profiles/JSON/*',
           'Spine Access Port Profiles/Markdown/*',
           'Spine Access Port Profiles/Mindmap/*',
           'Spine Access Port Profiles/YAML/*',
           'Spine Host Port Selectors/CSV/*',
           'Spine Host Port Selectors/HTML/*',
           'Spine Host Port Selectors/JSON/*',
           'Spine Host Port Selectors/Markdown/*',
           'Spine Host Port Selectors/Mindmap/*',
           'Spine Host Port Selectors/YAML/*',
           'Spine Interface Profiles/CSV/*',
           'Spine Interface Profiles/HTML/*',
           'Spine Interface Profiles/JSON/*',
           'Spine Interface Profiles/Markdown/*',
           'Spine Interface Profiles/Mindmap/*',
           'Spine Interface Profiles/YAML/*',
           'Spine Switch Profiles/CSV/*',
           'Spine Switch Profiles/HTML/*',
           'Spine Switch Profiles/JSON/*',
           'Spine Switch Profiles/Markdown/*',
           'Spine Switch Profiles/Mindmap/*',
           'Spine Switch Profiles/YAML/*',
           'Static Route Next Hop Policies/CSV/*',
           'Static Route Next Hop Policies/HTML/*',
           'Static Route Next Hop Policies/JSON/*',
           'Static Route Next Hop Policies/Markdown/*',
           'Static Route Next Hop Policies/Mindmap/*',
           'Static Route Next Hop Policies/YAML/*',
           'Subnets/CSV/*',
           'Subnets/HTML/*',
           'Subnets/JSON/*',
           'Subnets/Markdown/*',
           'Subnets/Mindmap/*',
           'Subnets/YAML/*',
           'Tenant Health/CSV/*',
           'Tenant Health/HTML/*',
           'Tenant Health/JSON/*',
           'Tenant Health/Markdown/*',
           'Tenant Health/Mindmap/*',
           'Tenant Health/YAML/*',
           'Tenant/CSV/*',
           'Tenant/HTML/*',
           'Tenant/JSON/*',
           'Tenant/Markdown/*',
           'Tenant/Mindmap/*',
           'Tenant/YAML/*',
           'Top System/CSV/*',
           'Top System/HTML/*',
           'Top System/JSON/*',
           'Top System/Markdown/*',
           'Top System/Mindmap/*',
           'Top System/YAML/*',
           'Users/CSV/*',
           'Users/HTML/*',
           'Users/JSON/*',
           'Users/Markdown/*',
           'Users/Mindmap/*',
           'Users/YAML/*',
           'VLAN Encapsulation Blocks/CSV/*',
           'VLAN Encapsulation Blocks/HTML/*',
           'VLAN Encapsulation Blocks/JSON/*',
           'VLAN Encapsulation Blocks/Markdown/*',
           'VLAN Encapsulation Blocks/Mindmap/*',
           'VLAN Encapsulation Blocks/YAML/*',
           'VLAN Namespace Policies/CSV/*',
           'VLAN Namespace Policies/HTML/*',
           'VLAN Namespace Policies/JSON/*',
           'VLAN Namespace Policies/Markdown/*',
           'VLAN Namespace Policies/Mindmap/*',
           'VLAN Namespace Policies/YAML/*',
           'VLAN Namespace Source Relationships/CSV/*',
           'VLAN Namespace Source Relationships/HTML/*',
           'VLAN Namespace Source Relationships/JSON/*',
           'VLAN Namespace Source Relationships/Markdown/*',
           'VLAN Namespace Source Relationships/Mindmap/*',
           'VLAN Namespace Source Relationships/YAML/*',
           'VLAN Pools/CSV/*',
           'VLAN Pools/HTML/*',
           'VLAN Pools/JSON/*',
           'VLAN Pools/Markdown/*',
           'VLAN Pools/Mindmap/*',
           'VLAN Pools/YAML/*',
           'Wired Nodes/CSV/*',
           'Wired Nodes/HTML/*',
           'Wired Nodes/JSON/*',
           'Wired Nodes/Markdown/*',
           'Wired Nodes/Mindmap/*',
           'Wired Nodes/YAML/*']}

install_requires = \
['Jinja2>=3.1.2,<4.0.0',
 'PyYAML>=6.0,<7.0',
 'requests>=2.28.1,<3.0.0',
 'rich-click>=1.5.1,<2.0.0']

entry_points = \
{'console_scripts': ['aceye = aceye.script:run']}

setup_kwargs = {
    'name': 'aceye',
    'version': '1.3.37',
    'description': 'Business ready documents from Cisco ACI',
    'long_description': '[![published](https://static.production.devnetcloud.com/codeexchange/assets/images/devnet-published.svg)](https://developer.cisco.com/codeexchange/github/repo/automateyournetwork/ACEye)\n\n# ACEye\n\nBusiness Ready Documents for Cisco ACI\n\n## Current API Coverage\n\nAccess Bundle Groups\n\nAccess Control Entities\n\nAccess Control Instances\n\nAccess Control Rules\n\nAccess Control Scope\n\nAccess Policy Group Source Relationships\n\nAccess Port Groups\n\nAccess Port Profiles\n\nApplication Profiles\n\nARP Adjacency Endpoints\n\nARP Database\n\nARP Domain\n\nARP Entity\n\nARP Instances\n\nARP Interfaces\n\nAttachable Access Entity Profiles\n\nAttachable Access Entity Profiles Source Relationships\n\n*Audit Log\n\nBGP Address Families\n\nBGP Domains\n\nBGP Entities\n\nBGP Instances\n\nBGP Instances Policy\n\nBGP Peers\n\nBGP Peers AF Entries\n\nBGP Peers Entries\n\nBGP Route Reflector Policy\n\nBGP Route Reflectors\n\nBridge Domains\n\nBridge Domains Target Relationships\n\nBridge Domains To Outside\n\nCDP Adjacency Endpoints\n\nCDP Entities\n\nCDP Instances\n\nCDP Interface Addresses\n\nCDP Interfaces\n\nCDP Management Addresses\n\nCluster Aggregate Interfaces\n\nCluster Health\n\nCluster Physical Interfaces\n\nCluster RS Member Interfaces\n\nCompute Controllers\n\nCompute Domains\n\nCompute Endpoint Policy Descriptions\n\nCompute Providers\n\nCompute RS Domain Policies\n\nContext Source Relationships\n\nContexts (VRFs)\n\nContexts Target Relationships\n\nContracts\n\nContract Consumer Interfaces\n\nContract Consumers\n\nContract Providers\n\nContract Subjects\n\nControllers\n\nDevice Packages\n\nDomain Attachments\n\nDomain Profile Source Relationships\n\nEndpoint Profile Containers\n\nEndpoints (All Connected Fabric Endpoints)\n\nEndpoints To Paths\n\nEPG to Bridge Domain Links\n\nEPGs (Endpoint Groups)\n\nEquipment Board Slots\n\nEquipment Boards\n\nEquipment Chassis\n\nEquipment CPUs\n\nEquipment DIMMs\n\nEquipment Fabric Extenders\n\nEquipment Fabric Ports\n\nEquipment Fan Slots\n\nEquipment Fan Trays\n\nEquipment Fans\n\nEquipment Field Programmable Gate Arrays\n\nEquipment Indicator LEDs\n\nEquipment Leaf Ports\n\nEquipment Line Card Slots\n\nEquipment Line Cards\n\nEquipment Port Locator LEDs\n\nEquipment Power Supplies\n\nEquipment Power Supply Slots\n\nEquipment RS IO Port Physical Configs\n\nEquipment Sensors\n\nEquipment SP Common Blocks\n\nEquipment SPROM LCs\n\nEquipment SPROM Power Supplies\n\nEquipment SPROM Power Supply Blocks\n\nEquipment SPROM Supervisors\n\nEquipment Storage\n\nEquipment Supervisor Slots\n\nEquipment Supervisors\n\nEthernet Port Manager Physical Interfaces\n\n*Events\n\nFabric Extended Path Endpoint Containers\n\nFabric Instances\n\nFabric Link Containers\n\nFabric Links\n\nFabric Loose Links\n\nFabric Loose Nodes\n\nFabric Membership\n\nFabric Node SSL Certifcates\n\nFabric Nodes\n\nFabric Path Endpoint Containers\n\nFabric Path Endpoints\n\nFabric Paths\n\nFabric Pods\n\nFabric Protected Path Endpoint Containers\n\nFault Summary\n\nFEX Policies\n\nFibre Channel Entity\n\nFilters\n\nFirmware Card Running\n\nFirmware Compute Running\n\nFirmware Running\n\nFunction Policies\n\nHealth\n\nHost Port Selectors\n\nInterface Policies\n\nInterface Profiles\n\nIP Addresses\n\nIPv4 Addresses\n\nIPv4 Domains\n\nIPv4 Entities\n\nIPv4 Instances\n\nIPv4 Interfaces\n\nIPv4 Next Hop\n\nIPv4 Routes\n\nISIS Adjacency Endpoints\n\nISIS Discovered Tunnel Endpoints\n\nISIS Domains\n\nISIS Domains Level\n\nISIS Entities\n\nISIS Instances\n\nISIS Interfaces\n\nISIS Interfaces Level\n\nISIS Next Hop\n\nISIS Routes\n\nLicense Entitlements\n\nL2 Bridge Domains\n\nL2 EPG Bridge Domain Source Relationships\n\nL2 External Instance Profiles\n\nL2 External Interfaces\n\nL2 External Logical Interface Profiles\n\nL2 External Logical Node Profiles\n\nL2 Interface Source Relationships\n\nL2Out Paths\n\nL2Outs\n\nL3 Contexts\n\nL3 Contexts Source Relationships\n\nL3 Domains\n\nL3 Domains Source Relationships\n\nL3 Instances\n\nL3 Interfaces\n\nL3 Logical Interface Profiles\n\nL3 Logical Node Profiles\n\nL3 Physical Interface Source Relationships\n\nL3 Routed Interfaces\n\nL3 Routed Loopback Interfaces\n\nL3 Subinterfaces\n\nL3 Subnets\n\nL3Out IP Addresses\n\nL3Out Members\n\nL3Out Node Source Relationships\n\nL3Out Path Source Relationships\n\nL3Out Profiles\n\nL3Outs\n\nLeaf Interface Profiles\n\nLeaf Switch Profiles\n\nLocales\n\nPath Attachments\n\nPhysical Domains\n\nPhysical Interfaces\n\nPort Blocks\n\nPrefix List\n\nPrefix List Detailed\n\nQOS Classes\n\nRoute Policies\n\nSecurity Domains\n\nSpine Access Policy Groups\n\nSpine Access Port Profiles\n\nSpine Host Port Selectors\n\nSpine Interface Profiles\n\nSpine Switch Profiles\n\nStatic Route Next Hop Policies\n\nSubnets\n\nTenant\n\nTenant Health\n\nTop System\n\nUsers\n\nVLAN Encapsulation Blocks\n\nVLAN Namespace Policies\n\nVLAN Namespace Source Relationships\n\nVLAN Pools\n\nWired Nodes\n\n* Both Audit Log and Events are commented out of the base package due to the potentially huge number of records; should you want the Audit Log / Events please uncomment out lines 72-73 (Audit Log) and 76-77 (Events)\n\n\n## Installation\n\n```console\n$ python3 -m venv ACI\n$ source ACI/bin/activate\n(ACI) $ pip install aceye\n```\n\n## Usage - Help\n\n```console\n(ACI) $ aceye --help\n```\n\n![ACEye Help](/images/help.png)\n\n## Usage - In-line\n\n```console\n(ACI) $ aceye --url <url to APIC> --username <APIC username> --password <APIC password>\n```\n\n## Usage - Interactive\n\n```console\n(ACI) $ aceye\nAPIC URL: <URL to APIC>\nAPIC Username: <APIC Username>\nAPIC Password: <APIC Password>\n```\n\n## Usage - Environment Variables\n\n```console\n(ACI) $ export URL=<URL to APIC>\n(ACI) $ export USERNAME=<APIC Username>\n(ACI) $ export PASSWORD=<APIC Password>\n```\n\n## Recommended VS Code Extensions\n\nExcel Viewer - CSV Files\n\nMarkdown Preview - Markdown Files\n\nMarkmap - Mindmap Files\n\nOpen in Default Browser - HTML Files\n\n## Contact\n\nPlease contact John Capobianco if you need any assistance\n',
    'author': 'John Capobianco',
    'author_email': 'ptcapo@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
